summaryrefslogtreecommitdiffstats
path: root/kdat/FormatOptDlg.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdat/FormatOptDlg.h')
-rw-r--r--kdat/FormatOptDlg.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kdat/FormatOptDlg.h b/kdat/FormatOptDlg.h
index db557e9..cdb2512 100644
--- a/kdat/FormatOptDlg.h
+++ b/kdat/FormatOptDlg.h
@@ -43,10 +43,10 @@ public:
* Create a new format options dialog.
*
* @param def The default value for the tape name.
* @param tqparent The tqparent widget for the dialog.
* @param name The name for the dialog.
*/
- FormatOptDlg( const TQString & def, TQWidget* tqparent=0, const char* name=0 );
+ FormatOptDlg( const TQString & def, TQWidget* parent=0, const char* name=0 );
/**
* Destroy the format options dialog.
@@ -43,10 +43,10 @@ public:
*
* @param def The default value for the tape name.
- * @param tqparent The tqparent widget for the dialog.
+ * @param parent The parent widget for the dialog.
* @param name The name for the dialog.
*/